@@ -2,7 +2,7 @@
 
 from lxml.html import HtmlElement
 
-def getTreeElement(tree: HtmlElement, expr, index=0):
+def getTreeElement(tree: HtmlElement, expr='', index=0):
     """ 根据表达式从`xmltree`中获取匹配值,默认 index 为 0
     :param tree (html.HtmlElement)
     :param expr 
@@ -16,16 +16,16 @@ def getTreeElement(tree: HtmlElement, expr, index=0):
     except:
         return ''
 
-def getTreeAll(tree: HtmlElement, expr):
+def getTreeAll(tree: HtmlElement, expr=''):
     """ 根据表达式从`xmltree`中获取全部匹配值
     :param tree (html.HtmlElement)
     :param expr 
     :param index
     """
     if expr == '':
-        return ''
+        return []
     result = tree.xpath(expr)
     try:
         return result
     except:
-        return ''
+        return []
